@@ -101,8 +101,17 @@ def plot_point(pos, marker="bs", text=None, ax=None, textargs=None, **kwargs):
       vertically aligned.
 
     - Multiple points can be marked if ``pos`` is a 2xn array or a list of
-      coordinate pairs.  If a label is provided every point will have the same
-      label.
+      coordinate pairs.  In this case:
+        - all points have the same ``text`` label
+        - ``text`` can include the format string {} which is susbstituted for the
+          point index, starting at zero
+        - ``text`` can be a tuple containing a format string followed by vectors
+          of shape(n).  For example::
+
+            ``("#{0} a={1:.1f}, b={2:.1f}", a, b)``
+
+          will label each point with its index (argument 0) and consecutive
+          elements of ``a`` and ``b`` which are arguments 1 and 2 respectively.
 
     Examples:
 
@@ -119,6 +128,7 @@ def plot_point(pos, marker="bs", text=None, ax=None, textargs=None, **kwargs):
     - ``plot_point(p, 'r*', ('{1:.1f}', z))`` plot red star at points defined by
       columns of ``p`` and label them all with successive elements of ``z``.
     """
+
     if isinstance(pos, np.ndarray):
         if pos.ndim == 1:
             x = pos[0]
@@ -608,9 +618,9 @@ def sphere(radius=1, centre=(0, 0, 0), resolution=50):
 
     Phi, Theta = np.meshgrid(phi_range, theta_range)
 
-    x = radius * np.sin(Theta) * np.cos(Phi)
-    y = radius * np.sin(Theta) * np.sin(Phi)
-    z = radius * np.cos(Theta)
+    x = radius * np.sin(Theta) * np.cos(Phi) + centre[0]
+    y = radius * np.sin(Theta) * np.sin(Phi) + centre[1]
+    z = radius * np.cos(Theta) + centre[2]
 
     return (x, y, z)
 
@@ -1134,6 +1144,7 @@ def plotvol2(dim, ax=None, equal=True, grid=False, labels=True):
         ax.set_aspect("equal")
     if grid:
         ax.grid(True)
+        ax.set_axisbelow(True)
 
     # signal to related functions that plotvol set the axis limits
     ax._plotvol = True
