@@ -1186,9 +1186,16 @@ if __name__ == '__main__':   # pragma: no cover
     import pathlib
     import os.path
 
-    a = Plane3([0.1, -1, -1, 2])
-    base.plotvol3(5)
-    a.plot(color='r', alpha=0.3)
+    from spatialmath import Twist3
+
+    base.plotvol3(10)
+    S = Twist3.UnitRevolute([0, 0, 1], [2, 3, 2], 0.5);
+    L = S.line()
+    L.plot('k:', linewidth=2)
+
+    # a = Plane3([0.1, -1, -1, 2])
+    # base.plotvol3(5)
+    # a.plot(color='r', alpha=0.3)
     plt.show(block=True)
     
     # a = SE3.Exp([2,0,0,0,0,0])
