@@ -163,26 +163,6 @@ class BaseTwist(BasePoseList):
             return [base.isunitvec(x) for x in self.data]
 
     @property
-    def unit(self):
-        """
-        Unitize twist (superclass property)
-
-        :return: a unit twist
-        :rtype: Twist3 or Twist2
-
-        - ``S.unit()`` is a Twist3 object representing a unit twist aligned with the
-        Twist ``S``.
-
-        Example:
-
-        .. runblock:: pycon
-
-            >>> from spatialmath import Twist3
-            >>> S = Twist3([1,2,3,4,5,6])
-            >>> S.unit()
-        """
-        return Twist3(base.unitvec(self.S))
-
     def theta(self):
         """
         Twist angle (superclass method)
@@ -300,6 +280,12 @@ class BaseTwist(BasePoseList):
             raise TypeError('operands to != are of different types')
         return left.binop(right, lambda x, y: not all(x == y), list1=False)
 
+    def __truediv__(left, right):  # lgtm[py/not-named-self] pylint: disable=no-self-argument
+        if base.isscalar(right):
+            return Twist3(left.S / right)
+        else:
+            raise ValueError('Twist /, incorrect right operand')
+
 # ======================================================================== #
 
 
@@ -488,9 +474,9 @@ class Twist3(BaseTwist):
     # -------------------- variant constructors ----------------------------#
 
     @classmethod
-    def Revolute(cls, a, q, pitch=None):
+    def UnitRevolute(cls, a, q, pitch=None):
         """
-        Construct a new unit rotational 3D twist
+        Construct a new 3D rotational unit twist
 
         :param a: Twist axis or line of action
         :type a: array_like(3)
@@ -517,9 +503,9 @@ class Twist3(BaseTwist):
         return cls(v, w)
 
     @classmethod
-    def Prismatic(cls, a):
+    def UnitPrismatic(cls, a):
         """
-        Construct a new unit prismatic 3D twist
+        Construct a new 3D unit prismatic twist
 
         :param a: Twist axis or line of action
         :type a: array_like(3)
@@ -752,6 +738,32 @@ class Twist3(BaseTwist):
 
     # -------------------------  methods -------------------------------#
 
+    def printline(self, **kwargs):
+        return self.SE3().printline(**kwargs)
+
+    def unit(self):
+        """
+        Unit twist
+
+        - ``S.unit()`` is a Twist2 objec3 representing a unit twist aligned with the
+          Twist ``S``.
+
+        Example:
+        
+        .. runblock:: pycon
+
+            >>> from spatialmath import SE3, Twist3
+            >>> T = SE3(1, 2, 0.3)
+            >>> S = Twist3(T)
+            >>> S.unit()
+        """
+        if base.iszerovec(self.w):
+            # rotational twist
+            return Twist3(self.S / base.norm(S.w))
+        else:
+            # prismatic twist
+            return Twist3(base.unitvec(self.v), [0, 0, 0])
+
     def ad(self):
         """
         Logarithm of adjoint of 3D twist
@@ -811,27 +823,7 @@ class Twist3(BaseTwist):
         """
         return self.SE3().Ad()
 
-    def SE3(self):
-        """
-        Convert 3D twist to SE(3) matrix
 
-        :return: an SE(3) representation
-        :rtype: SE3 instance
-
-        ``S.SE3()`` is an SE3 object representing the homogeneous transformation 
-        equivalent to the Twist3. This is the exponentiation of the twist vector.
-
-        Example:
-        
-        .. runblock:: pycon
-
-            >>> from spatialmath import Twist3
-            >>> S = Twist3.Rx(0.3)
-            >>> S.SE3()
-
-        :seealso: :func:`Twist3.exp`
-        """
-        return SE3(self.exp())
 
     def se3(self):
         """
@@ -858,6 +850,7 @@ class Twist3(BaseTwist):
         else:
             return [base.skewa(x.S) for x in self]
 
+    @property
     def pitch(self):
         """
         Pitch of a 3D twist
@@ -879,7 +872,7 @@ class Twist3(BaseTwist):
             >>> from spatialmath import SE3, Twist3
             >>> T = SE3(1, 2, 3) * SE3.Rx(0.3)
             >>> S = Twist3(T)
-            >>> S.pitch()
+            >>> S.pitch
 
         """
         return np.dot(self.w, self.v)
@@ -902,8 +895,9 @@ class Twist3(BaseTwist):
             >>> S = Twist3(T)
             >>> S.line()
         """
-        return Line3([Line3(-tw.v - tw.pitch() * tw.w, tw.w) for tw in self])
+        return Line3([Line3(-tw.v - tw.pitch * tw.w, tw.w) for tw in self])
 
+    @property
     def pole(self):
         """
         Pole of a 3D twist
@@ -921,34 +915,46 @@ class Twist3(BaseTwist):
             >>> from spatialmath import SE3, Twist3
             >>> T = SE3(1, 2, 3) * SE3.Rx(0.3)
             >>> S = Twist3(T)
-            >>> S.pole()
+            >>> S.pole
         """
-        return np.cross(self.w, self.v) / self.theta()
+        return np.cross(self.w, self.v) / self.theta
 
-    def theta(self):
+    def SE3(self, theta=1, unit='rad'):
         """
-        Twist rotation
+        Convert 3D twist to SE(3) matrix
 
-        :return: rotation about the twist axis
-        :rtype: float
+        :return: an SE(3) representation
+        :rtype: SE3 instance
 
-        ``X.theta`` is the rotation about the twist axis in units of radians.
-
-        If we consider the twist as a screw, this is the rotation about the
-        screw axis to achieve the rigid-body motion.
+        ``S.SE3()`` is an SE3 object representing the homogeneous transformation 
+        equivalent to the Twist3. This is the exponentiation of the twist vector.
 
         Example:
         
         .. runblock:: pycon
 
-            >>> from spatialmath import SE3, Twist3
-            >>> T = SE3(1, 2, 3) * SE3.Rx(0.3)
-            >>> S = Twist3(T)
-            >>> S.theta()
-        """
-        return base.norm(self.w)
+            >>> from spatialmath import Twist3
+            >>> S = Twist3.Rx(0.3)
+            >>> S.SE3()
 
-    def exp(self, theta=None, unit='rad'):
+        :seealso: :func:`Twist3.exp`
+        """
+        theta = base.getunit(theta, unit)
+
+        if base.isscalar(theta):
+            # theta is a scalar
+            return SE3(base.trexp(self.S * theta))
+        else:
+            # theta is a vector
+            if len(self) == 1:
+                return SE3([base.trexp(self.S * t) for t in theta])
+            elif len(self) == len(theta):
+                return SE3([base.trexp(S * t) for S, t in zip(self.data, theta)])
+            else:
+                raise ValueError('length of twist and theta not consistent')
+        return SE3(self.exp(theta))
+
+    def exp(self, theta=1, unit='rad'):
         """
         Exponentiate a 3D twist
 
@@ -981,26 +987,9 @@ class Twist3(BaseTwist):
 
         :seealso: :func:`spatialmath.base.trexp`
         """
-        if unit != 'rad' and self.isprismatic:
-            print('Twist3.exp: using degree mode for a prismatic twist')
-
-        if theta is None:
-            theta = 1
-        else:
-            theta = base.getunit(theta, unit)
-
-        if base.isscalar(theta):
-            # theta is a scalar
-            return SE3(base.trexp(self.S * theta))
-        else:
-            # theta is a vector
-            if len(self) == 1:
-                return SE3([base.trexp(self.S * t) for t in theta])
-            elif len(self) == len(theta):
-                return SE3([base.trexp(S * t) for S, t in zip(self.data, theta)])
-            else:
-                raise ValueError('length of twist and theta not consistent')
+        theta = base.getunit(theta, unit)
 
+        return base.trexp(self.S * theta)
 
 
     # ------------------------- arithmetic -------------------------------#
@@ -1079,7 +1068,7 @@ class Twist3(BaseTwist):
         - ``s * X`` performs elementwise multiplication of the elements of ``X`` by ``s``
         """
         if base.isscalar(left):
-            return Twist3(self.S * left)
+            return Twist3(right.S * left)
         else:
             raise ValueError('Twist3 *, incorrect left operand')
 
@@ -1259,9 +1248,9 @@ class Twist2(BaseTwist):
     # -------------------- variant constructors ----------------------------#
 
     @classmethod
-    def Revolute(cls, q):
+    def UnitRevolute(cls, q):
         """
-        Construct a new 2D revolute Twist object
+        Construct a new 2D revolute unit twist
 
         :param q: Point on the line of action
         :type q: array_like(2)
@@ -1283,9 +1272,9 @@ class Twist2(BaseTwist):
         return cls(v[:2], 1)
 
     @classmethod
-    def Prismatic(cls, a):
+    def UnitPrismatic(cls, a):
         """
-        Construct a new 2D primsmatic Twist object
+        Construct a new 2D primsmatic unit twist
 
         :param a: Displacment
         :type a: array-like(2)
@@ -1371,9 +1360,35 @@ class Twist2(BaseTwist):
         """
         return self.data[0][2]
 
+    @property
+    def pole(self):
+        """
+        Pole of a 2D twist
+
+        :return: the pole of the twist
+        :rtype: ndarray(2)
+
+        ``X.pole()`` is a point on the twist axis. For a pure translation 
+        this point is at infinity.
+
+        Example:
+        
+        .. runblock:: pycon
+
+            >>> from spatialmath import SE3, Twist3
+            >>> T = SE2(1, 2, 0.3)
+            >>> S = Twist2(T)
+            >>> S.pole()
+        """
+        p = np.cross(np.r_[0, 0, self.w], np.r_[self.v, 0]) / self.theta
+        return p[:2]
+
     # -------------------------  methods -------------------------------#
 
-    def SE2(self):
+    def printline(self, **kwargs):
+        return self.SE2().printline(**kwargs)
+
+    def SE2(self, theta=1, unit='rad'):
         """
         Convert 2D twist to SE(2) matrix
 
@@ -1393,8 +1408,18 @@ class Twist2(BaseTwist):
 
         :seealso: :func:`Twist3.exp`
         """
+        if unit != 'rad' and self.isprismatic:
+            print('Twist3.exp: using degree mode for a prismatic twist')
 
-        return SE2(self.exp())
+        if theta is None:
+            theta = 1
+        else:
+            theta = base.getunit(theta, unit)
+
+        if base.isscalar(theta):
+            return SE2(base.trexp2(self.S * theta))
+        else:
+            return SE2([base.trexp2(self.S * t) for t in theta])
 
     def se2(self):
         """
@@ -1454,43 +1479,14 @@ class Twist2(BaseTwist):
 
         :seealso: :func:`spatialmath.base.trexp2`
         """
-
-        if unit != 'rad' and self.isprismatic:
-            print('Twist3.exp: using degree mode for a prismatic twist')
-
         if theta is None:
-            theta = 1
+            theta = 1.0
         else:
             theta = base.getunit(theta, unit)
 
-        if base.isscalar(theta):
-            return SE2(base.trexp2(self.S * theta))
-        else:
-            return SE2([base.trexp2(self.S * t) for t in theta])
+        return base.trexp2(self.S * theta)
 
-    def pole(self):
-        """
-        Pole of a 2D twist
 
-        :return: the pole of the twist
-        :rtype: ndarray(2)
-
-        ``X.pole()`` is a point on the twist axis. For a pure translation 
-        this point is at infinity.
-
-        Example:
-        
-        .. runblock:: pycon
-
-            >>> from spatialmath import SE3, Twist3
-            >>> T = SE2(1, 2, 0.3)
-            >>> S = Twist2(T)
-            >>> S.pole()
-        """
-        p = np.cross(np.r_[0, 0, self.w], np.r_[self.v, 0]) / self.theta()
-        return p[:2]
-
-    @property
     def unit(self):
         """
         Unit twist
